## 2.8.1 (2021-11-23)

Reduce use of deprecated `typing` aliases (#6358)

## 2.8.0 (2021-11-18)

Add `prefetch` argument to paramiko SFTPClient.getfo (#6331)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.7.4 (2021-11-08)

paramiko.ServerInterface: replace str with bytes in some methods (#6254)

## 2.7.3 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 2.7.2 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 2.7.1 (2021-10-05)

Properly export bytes from paramiko.py3compat (#6113)

## 2.7.0 (2021-09-19)

Update third-party package versions (#5996)

